const Generator = require('yeoman-generator');

module.exports = class extends Generator {
  constructor(args, opts) {
    super(args, opts);
    this.argument("environment", { type: String, desc: '运行环境', required: false });
    this.option("public", { type: String, desc: '公共路径' });
    const env = opts.env.options.environment ?? this.options.environment;
    const public1 = opts.env.options.public ?? this.options.public
    this.log(env, public1);
  }

  initializing() {
    this.composeWith(require.resolve('../router'));
    this.composeWith(require.resolve('../other'));
  }

  prompting() {

    const prompts = [
      {
        type: 'input',
        name: 'projectName',
        message: 'please input the project name.',
        default: process.name
      },
      {
        type: 'confirm',
        name: 'use',
        message: 'Would you like to enable this option?',
        default: true,
        store: true
      }, {
        type: 'list',
        name: 'framework',
        message: 'choose framework',
        choices: ['react', 'vue', 'typescript'],
        default: 'vue',
        store: true
      }
    ];

    return this.prompt(prompts).then(props => {
      this.props = props;
      this.log(`name: ${this.props.projectName}, use: ${this.props.use}, framework: ${this.props.framework}`)
    });
  }

  writing() {
    this.fs.copyTpl(
      this.templatePath('index.html'),
      this.destinationPath(`${this.props.projectName}/index.html`),
      { 
        title: this.props.projectName,
        evn: this.options.env.options.environment ?? this.options.environment,
        public: this.options.env.options.public ?? this.options.public,
        framework: this.props.framework
       }
    );
    const pkgJson = {
      devDependencies: {
        eslint: '^3.15.0'
      },
      dependencies: {
        react: '^16.2.0'
      }
    };

    this.fs.extendJSON(this.destinationPath('package.json'), pkgJson);
  }

  // install() {
  //   this.installDependencies({
  //     npm: true,
  //     bower: false,
  //     yarn: true
  //   });
  // }

  end() {
    this.config.save();
  }
};